# -*- coding: utf-8 -*-
"""The switchboard-tg2 package"""


def plugme(app_config, options):
    def switchboard_setup(app):
        from tg import config, request
        from switchboard import configure, operator
        # Setup the global operator for our switchboard switches
        configure(config, nested=True)
        # Hook the operator up to the user and request objects
        #operator.get_user = lambda: self.user
        # request is actually a StackedObjectProxy and we want the underlying
        # webob.Request object
        operator.get_request = lambda: request._current_obj()
        return app
    app_config.register_hook('after_config', switchboard_setup)
    return dict(appid='switchboard', global_helpers=False)



# -*- coding: utf-8 -*-
"""Main Controller"""
from tg import TGController, expose

from switchboard.admin.controllers import CoreAdminController


class RootController(TGController):
    def __init__(self):
        super(RootController, self).__init__()
        self._c = CoreAdminController()

    @expose('mako:switchboard.admin.templates.index')
    def index(self, by='-date_modified'):
        return self._c.index(by)

    @expose('json')
    def add(self, key, label='', description=None, **kwargs):
        return self._c.add(key, label, description, **kwargs)

    @expose('json')
    def update(self, curkey, key, label='', description=None):
        return self._c.update(curkey, key, label, description)

    @expose('json')
    def status(self, key, status):
        return self._c.status(key, status)

    @expose('json')
    def delete(self, key):
        return self._c.delete(key)

    @expose('json')
    def add_condition(self, *args, **kwargs):
        return self._c.add_condition(*args, **kwargs)

    @expose('json')
    def remove_condition(self, *args, **kwargs):
        return self._c.remove_condition(*args, **kwargs)



# -*- coding: utf-8 -*-
import os

try:
    from setuptools import setup, find_packages
except ImportError:
    from ez_setup import use_setuptools
    use_setuptools()
    from setuptools import setup, find_packages

install_requires = [
    "TurboGears2 >= 2.1.4",
    "tg.devtools",
    "tgext.pluggable",
    "switchboard",
]

here = os.path.abspath(os.path.dirname(__file__))
try:
    README = open(os.path.join(here, 'README.rst')).read()
except IOError:
    README = ''

setup(
    name='switchboard-tg2',
    version='0.3',
    description='',
    long_description=README,
    author='Kyle Adams',
    author_email='kadams54@users.sourceforge.net',
    url='http://sf.net/projects/switchboard-tg2',
    keywords='turbogears2.application',
    setup_requires=["PasteScript >= 1.7"],
    paster_plugins=[],
    packages=find_packages(exclude=['ez_setup']),
    install_requires=install_requires,
    include_package_data=True,
    entry_points="""
    """,
    dependency_links=[
        "http://www.turbogears.org/2.1/downloads/current/"
        ],
    zip_safe=False
)
